@@ -11,12 +11,15 @@ from .utils import (
     rotate,
     resize,
     perspective,
+    motion_blur,
     square,
     fit_size,
     FitSizeMode,
+    FitSizeDir,
     to_jpg,
     save_jpg,
     save_gif,
+    make_jpg_or_gif,
     load_image,
     load_font,
     fit_font_size,
@@ -53,36 +56,16 @@ async def kiss(users: List[UserInfo], sender: UserInfo, **kwargs) -> BytesIO:
     else:
         self_img = sender.img
         user_img = users[0].img
+    # fmt: off
     user_locs = [
-        (58, 90),
-        (62, 95),
-        (42, 100),
-        (50, 100),
-        (56, 100),
-        (18, 120),
-        (28, 110),
-        (54, 100),
-        (46, 100),
-        (60, 100),
-        (35, 115),
-        (20, 120),
-        (40, 96),
+        (58, 90), (62, 95), (42, 100), (50, 100), (56, 100), (18, 120), (28, 110),
+        (54, 100), (46, 100), (60, 100), (35, 115), (20, 120), (40, 96)
     ]
     self_locs = [
-        (92, 64),
-        (135, 40),
-        (84, 105),
-        (80, 110),
-        (155, 82),
-        (60, 96),
-        (50, 80),
-        (98, 55),
-        (35, 65),
-        (38, 100),
-        (70, 80),
-        (84, 65),
-        (75, 65),
+        (92, 64), (135, 40), (84, 105), (80, 110), (155, 82), (60, 96), (50, 80),
+        (98, 55), (35, 65), (38, 100), (70, 80), (84, 65), (75, 65)
     ]
+    # fmt: on
     frames = []
     for i in range(13):
         frame = await load_image(f"kiss/{i}.png")
@@ -101,22 +84,16 @@ async def rub(users: List[UserInfo], sender: UserInfo, **kwargs) -> BytesIO:
     else:
         self_img = sender.img
         user_img = users[0].img
+    # fmt: off
     user_locs = [
-        (39, 91, 75, 75),
-        (49, 101, 75, 75),
-        (67, 98, 75, 75),
-        (55, 86, 75, 75),
-        (61, 109, 75, 75),
-        (65, 101, 75, 75),
+        (39, 91, 75, 75), (49, 101, 75, 75), (67, 98, 75, 75),
+        (55, 86, 75, 75), (61, 109, 75, 75), (65, 101, 75, 75)
     ]
     self_locs = [
-        (102, 95, 70, 80, 0),
-        (108, 60, 50, 100, 0),
-        (97, 18, 65, 95, 0),
-        (65, 5, 75, 75, -20),
-        (95, 57, 100, 55, -70),
-        (109, 107, 65, 75, 0),
+        (102, 95, 70, 80, 0), (108, 60, 50, 100, 0), (97, 18, 65, 95, 0),
+        (65, 5, 75, 75, -20), (95, 57, 100, 55, -70), (109, 107, 65, 75, 0)
     ]
+    # fmt: on
     frames = []
     for i in range(6):
         frame = await load_image(f"rub/{i}.png")
@@ -132,26 +109,16 @@ async def rub(users: List[UserInfo], sender: UserInfo, **kwargs) -> BytesIO:
 
 async def play(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
+    # fmt: off
     locs = [
-        (180, 60, 100, 100),
-        (184, 75, 100, 100),
-        (183, 98, 100, 100),
-        (179, 118, 110, 100),
-        (156, 194, 150, 48),
-        (178, 136, 122, 69),
-        (175, 66, 122, 85),
-        (170, 42, 130, 96),
-        (175, 34, 118, 95),
-        (179, 35, 110, 93),
-        (180, 54, 102, 93),
-        (183, 58, 97, 92),
-        (174, 35, 120, 94),
-        (179, 35, 109, 93),
-        (181, 54, 101, 92),
-        (182, 59, 98, 92),
-        (183, 71, 90, 96),
-        (180, 131, 92, 101),
+        (180, 60, 100, 100), (184, 75, 100, 100), (183, 98, 100, 100),
+        (179, 118, 110, 100), (156, 194, 150, 48), (178, 136, 122, 69),
+        (175, 66, 122, 85), (170, 42, 130, 96), (175, 34, 118, 95),
+        (179, 35, 110, 93), (180, 54, 102, 93), (183, 58, 97, 92),
+        (174, 35, 120, 94), (179, 35, 109, 93), (181, 54, 101, 92),
+        (182, 59, 98, 92), (183, 71, 90, 96), (180, 131, 92, 101)
     ]
+    # fmt: on
     raw_frames = []
     for i in range(23):
         raw_frame = await load_image(f"play/{i}.png")
@@ -184,49 +151,53 @@ async def pat(users: List[UserInfo], **kwargs) -> BytesIO:
         raw_frame = await load_image(f"pat/{i}.png")
         frame.paste(raw_frame, mask=raw_frame)
         img_frames.append(frame)
-    seq = [
-        0,
-        1,
-        2,
-        3,
-        1,
-        2,
-        3,
-        0,
-        1,
-        2,
-        3,
-        0,
-        0,
-        1,
-        2,
-        3,
-        0,
-        0,
-        0,
-        0,
-        4,
-        5,
-        5,
-        5,
-        6,
-        7,
-        8,
-        9,
-    ]
+    # fmt: off
+    seq = [0, 1, 2, 3, 1, 2, 3, 0, 1, 2, 3, 0, 0, 1, 2, 3, 0, 0, 0, 0, 4, 5, 5, 5, 6, 7, 8, 9]
+    # fmt: on
     frames = [img_frames[n] for n in seq]
     return save_gif(frames, 0.085)
 
 
-async def rip(users: List[UserInfo], **kwargs) -> BytesIO:
-    img = users[0].img
-    rip = await load_image("rip/0.png")
+async def rip(
+    users: List[UserInfo], sender: UserInfo, args: List[str] = [], **kwargs
+) -> Union[str, BytesIO]:
+    if len(users) >= 2:
+        self_img = users[0].img
+        user_img = users[1].img
+    else:
+        self_img = sender.img
+        user_img = users[0].img
+
+    arg = "".join(args)
+    if "滑稽" in arg:
+        rip = await load_image("rip/0.png")
+    else:
+        rip = await load_image("rip/1.png")
+    text = arg.strip("滑稽").strip()
+
     frame = Image.new("RGBA", rip.size, (255, 255, 255, 0))
-    left = rotate(resize(img, (385, 385)), 24)
-    right = rotate(resize(img, (385, 385)), -11)
+    left = rotate(resize(user_img, (385, 385)), 24)
+    right = rotate(resize(user_img, (385, 385)), -11)
     frame.paste(left, (-5, 355))
     frame.paste(right, (649, 310))
+    frame.paste(resize(self_img, (230, 230)), (408, 418))
     frame.paste(rip, mask=rip)
+
+    if text:
+        fontname = DEFAULT_FONT
+        fontsize = await fit_font_size(text, rip.width - 50, 300, fontname, 150, 25)
+        if not fontsize:
+            return "文字太长了哦，改短点再试吧~"
+        font = await load_font(fontname, fontsize)
+        text_w = font.getsize(text)[0]
+        draw = ImageDraw.Draw(frame)
+        draw.text(
+            ((rip.width - text_w) / 2, 40),
+            text,
+            font=font,
+            fill="#FF0000",
+            stroke_width=2,
+        )
     return save_jpg(frame)
 
 
@@ -260,10 +231,14 @@ async def throw_gif(users: List[UserInfo], **kwargs) -> BytesIO:
     return save_gif(frames, 0.1)
 
 
-async def crawl(users: List[UserInfo], **kwargs) -> BytesIO:
+async def crawl(users: List[UserInfo], args: List[str] = [], **kwargs) -> BytesIO:
     img = users[0].img
     img = resize(circle(img), (100, 100))
-    frame = await load_image("crawl/{:02d}.jpg".format(random.randint(1, 92)))
+    crawl_total = 92
+    crawl_num = random.randint(1, crawl_total)
+    if args and args[0].isdigit() and 1 <= int(args[0]) <= crawl_total:
+        crawl_num = int(args[0])
+    frame = await load_image("crawl/{:02d}.jpg".format(crawl_num))
     frame.paste(img, (0, 400), mask=img)
     return save_jpg(frame)
 
@@ -286,7 +261,7 @@ async def always(users: List[UserInfo], **kwargs) -> BytesIO:
     h2 = int(h / w * 60)
     height = h1 + h2 + 10
 
-    def paste(img: IMG) -> IMG:
+    def make(img: IMG) -> IMG:
         img = to_jpg(img)
         frame = Image.new("RGBA", (300, height), (255, 255, 255, 0))
         frame.paste(always, (0, h1 - 300 + int((h2 - 60) / 2)))
@@ -294,14 +269,7 @@ async def always(users: List[UserInfo], **kwargs) -> BytesIO:
         frame.paste(resize(img, (60, h2)), (165, h1 + 5))
         return frame
 
-    if not getattr(img, "is_animated", False):
-        return save_jpg(paste(img))
-    else:
-        frames = []
-        for i in range(img.n_frames):
-            img.seek(i)
-            frames.append(paste(img))
-        return save_gif(frames, img.info["duration"] / 1000)
+    return make_jpg_or_gif(img, make)
 
 
 async def loading(users: List[UserInfo], **kwargs) -> BytesIO:
@@ -313,7 +281,7 @@ async def loading(users: List[UserInfo], **kwargs) -> BytesIO:
     h2 = int(h / w * 60)
     height = h1 + h2 + 10
 
-    def paste_large(img: IMG) -> IMG:
+    def make_static(img: IMG) -> IMG:
         img = to_jpg(img)
         frame = Image.new("RGBA", (300, height), (255, 255, 255, 0))
         frame.paste(bg, (0, h1 - 300 + int((h2 - 60) / 2)))
@@ -325,20 +293,14 @@ async def loading(users: List[UserInfo], **kwargs) -> BytesIO:
         frame.paste(icon, (100, int(h1 / 2) - 50), mask=icon)
         return frame
 
-    def paste_small(frame: IMG, img: IMG) -> IMG:
-        img = to_jpg(img)
-        frame.paste(resize(img, (60, h2)), (60, h1 + 5))
-        return frame
+    frame = make_static(img)
 
-    if not getattr(img, "is_animated", False):
-        return save_jpg(paste_small(paste_large(img), img))
-    else:
-        frames = []
-        frame = paste_large(img)
-        for i in range(img.n_frames):
-            img.seek(i)
-            frames.append(paste_small(frame.copy(), img))
-        return save_gif(frames, img.info["duration"] / 1000)
+    def make(img: IMG) -> IMG:
+        new_img = frame.copy()
+        new_img.paste(resize(img, (60, h2)), (60, h1 + 5))
+        return new_img
+
+    return make_jpg_or_gif(img, make)
 
 
 async def turn(users: List[UserInfo], **kwargs) -> BytesIO:
@@ -412,16 +374,12 @@ async def alike(users: List[UserInfo], **kwargs) -> BytesIO:
 async def roll(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     frames = []
+    # fmt: off
     locs = [
-        (87, 77, 0),
-        (96, 85, -45),
-        (92, 79, -90),
-        (92, 78, -135),
-        (92, 75, -180),
-        (92, 75, -225),
-        (93, 76, -270),
-        (90, 80, -315),
+        (87, 77, 0), (96, 85, -45), (92, 79, -90), (92, 78, -135),
+        (92, 75, -180), (92, 75, -225), (93, 76, -270), (90, 80, -315)
     ]
+    # fmt: on
     for i in range(8):
         frame = Image.new("RGBA", (300, 300), (255, 255, 255, 0))
         x, y, a = locs[i]
@@ -432,23 +390,31 @@ async def roll(users: List[UserInfo], **kwargs) -> BytesIO:
     return save_gif(frames, 0.1)
 
 
-async def play_game(users: List[UserInfo], **kwargs) -> BytesIO:
+async def play_game(
+    users: List[UserInfo], args: List[str] = [], **kwargs
+) -> Union[str, BytesIO]:
     img = users[0].img
     bg = await load_image("play_game/0.png")
-    font = await load_font(DEFAULT_FONT, 35)
+    text = args[0] if args else "来玩休闲游戏啊"
+    fontname = DEFAULT_FONT
+    fontsize = await fit_font_size(text, 520, 110, fontname, 35, 25)
+    if not fontsize:
+        return "描述太长了哦，改短点再试吧~"
+    font = await load_font(fontname, fontsize)
+    text_w = font.getsize(text)[0]
 
     def make(img: IMG) -> IMG:
         img = to_jpg(img)
         frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
-        points = [(0, 5), (225, 0), (215, 150), (0, 165)]
+        points = [(0, 5), (227, 0), (216, 150), (0, 165)]
         screen = rotate(perspective(fit_size(img, (220, 160)), points), 9)
         frame.paste(screen, (161, 117))
         frame.paste(bg, mask=bg)
 
         draw = ImageDraw.Draw(frame)
         draw.text(
-            (150, 430),
-            "来玩休闲游戏啊",
+            (263 - text_w / 2, 430),
+            text,
             font=font,
             fill="#000000",
             stroke_fill="#FFFFFF",
@@ -456,14 +422,7 @@ async def play_game(users: List[UserInfo], **kwargs) -> BytesIO:
         )
         return frame
 
-    if not getattr(img, "is_animated", False):
-        return save_jpg(make(img))
-    else:
-        frames = []
-        for i in range(img.n_frames):
-            img.seek(i)
-            frames.append(make(img))
-        return save_gif(frames, img.info["duration"] / 1000)
+    return make_jpg_or_gif(img, make)
 
 
 async def worship(users: List[UserInfo], **kwargs) -> BytesIO:
@@ -499,14 +458,12 @@ async def bite(users: List[UserInfo], **kwargs) -> BytesIO:
         raw_frame = await load_image(f"bite/{i}.png")
         raw_frames.append(raw_frame)
     frames = []
+    # fmt: off
     locs = [
-        (90, 90, 105, 150),
-        (90, 83, 96, 172),
-        (90, 90, 106, 148),
-        (88, 88, 97, 167),
-        (90, 85, 89, 179),
-        (90, 90, 106, 151),
+        (90, 90, 105, 150), (90, 83, 96, 172), (90, 90, 106, 148),
+        (88, 88, 97, 167), (90, 85, 89, 179), (90, 90, 106, 151)
     ]
+    # fmt: on
     for i in range(6):
         frame = Image.new("RGBA", (362, 364), (255, 255, 255, 0))
         x, y, w, h = locs[i]
@@ -520,11 +477,21 @@ async def bite(users: List[UserInfo], **kwargs) -> BytesIO:
 
 async def police(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    frame = await load_image("police/0.png")
-    bg = Image.new("RGBA", frame.size)
-    bg.paste(resize(img, (245, 245)), (224, 46))
-    bg.paste(frame, mask=frame)
-    return save_jpg(bg)
+    bg = await load_image("police/0.png")
+    frame = Image.new("RGBA", bg.size)
+    frame.paste(resize(img, (245, 245)), (224, 46))
+    frame.paste(bg, mask=bg)
+    return save_jpg(frame)
+
+
+async def police1(users: List[UserInfo], **kwargs) -> BytesIO:
+    img = users[0].img
+    img = to_jpg(img).convert("RGBA")
+    bg = await load_image("police/1.png")
+    frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
+    frame.paste(rotate(fit_size(img, (60, 75)), 16), (37, 291))
+    frame.paste(bg, mask=bg)
+    return save_jpg(frame)
 
 
 async def ask(
@@ -593,32 +560,23 @@ async def prpr(users: List[UserInfo], **kwargs) -> BytesIO:
         img = to_jpg(img)
         frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
         points = [(0, 19), (236, 0), (287, 264), (66, 351)]
-        screen = perspective(fit_size(img, (330, 330), FitSizeMode.INCLUDE), points)
+        screen = perspective(fit_size(img, (330, 330)), points)
         frame.paste(screen, (56, 284))
         frame.paste(bg, mask=bg)
         return frame
 
-    if not getattr(img, "is_animated", False):
-        return save_jpg(make(img))
-    else:
-        frames = []
-        for i in range(img.n_frames):
-            img.seek(i)
-            frames.append(make(img))
-        return save_gif(frames, img.info["duration"] / 1000)
+    return make_jpg_or_gif(img, make)
 
 
 async def twist(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     frames = []
+    # fmt: off
     locs = [
-        (25, 66, 0),
-        (25, 66, 60),
-        (23, 68, 120),
-        (20, 69, 180),
-        (22, 68, 240),
-        (25, 66, 300),
+        (25, 66, 0), (25, 66, 60), (23, 68, 120),
+        (20, 69, 180), (22, 68, 240), (25, 66, 300)
     ]
+    # fmt: on
     for i in range(5):
         frame = Image.new("RGBA", (166, 168), (255, 255, 255, 0))
         x, y, a = locs[i]
@@ -636,21 +594,11 @@ async def wallpaper(users: List[UserInfo], **kwargs) -> BytesIO:
     def make(img: IMG) -> IMG:
         img = to_jpg(img)
         frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
-        frame.paste(fit_size(img, (775, 496), FitSizeMode.INCLUDE), (260, 580))
+        frame.paste(fit_size(img, (775, 496)), (260, 580))
         frame.paste(bg, mask=bg)
         return frame
 
-    if not getattr(img, "is_animated", False):
-        return save_jpg(make(img))
-    else:
-        frames = []
-        for i in range(img.n_frames):
-            img.seek(i)
-            ratio = 0.7
-            frames.append(
-                resize(make(img), (int(bg.width * ratio), int(bg.height * ratio)))
-            )
-        return save_gif(frames, img.info["duration"] / 1000)
+    return make_jpg_or_gif(img, make, gif_zoom=0.5)
 
 
 async def china_flag(users: List[UserInfo], **kwargs) -> BytesIO:
@@ -692,9 +640,11 @@ async def make_friend(
 
 async def back_to_work(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
-    bg = await load_image("back_to_work/0.png")
+    img = to_jpg(img).convert("RGBA")
+    bg = await load_image("back_to_work/1.png")
     frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
-    frame.paste(rotate(resize(img, (250, 250)), 20), (46, 43))
+    new_img = fit_size(img, (220, 310), direction=FitSizeDir.NORTH)
+    frame.paste(rotate(new_img, 25), (56, 32))
     frame.paste(bg, mask=bg)
     return save_jpg(frame)
 
@@ -702,14 +652,139 @@ async def back_to_work(users: List[UserInfo], **kwargs) -> BytesIO:
 async def perfect(users: List[UserInfo], **kwargs) -> BytesIO:
     img = users[0].img
     img = to_jpg(img).convert("RGBA")
-    img_w, img_h = img.size
-    block_w, block_h = (310, 460)
-    ratio = min(block_w / img_w, block_h / img_h)
-    img_w = int(img_w * ratio)
-    img_h = int(img_h * ratio)
-    img = resize(img, (img_w, img_h))
     frame = await load_image("perfect/0.png")
-    frame.paste(
-        img, (313 + int((block_w - img_w) / 2), 64 + int((block_h - img_h) / 2))
-    )
+    new_img = fit_size(img, (310, 460), mode=FitSizeMode.INSIDE)
+    frame.paste(new_img, (313, 64), mask=new_img)
     return save_jpg(frame)
+
+
+async def follow(
+    users: List[UserInfo], args: List[str] = [], **kwargs
+) -> Union[str, BytesIO]:
+    img = users[0].img
+    img = resize(circle(img), (200, 200))
+
+    font = await load_font(DEFAULT_FONT, 60)
+    ta = "女同" if users[0].gender == "female" else "男同"
+    name = (args[0] if args else "") or users[0].name or ta
+    text_name = name
+    text_name_w, text_name_h = font.getsize(text_name)
+    text_follow = "关注了你"
+    text_width = max(text_name_w, font.getsize(text_follow)[0])
+    if text_width >= 1000:
+        return "名字太长了哦，改短点再试吧~"
+
+    frame = Image.new("RGBA", (300 + text_width + 50, 300), (255, 255, 255, 0))
+    frame.paste(img, (50, 50), mask=img)
+    text_frame = Image.new("RGBA", (text_width + 50, 300), (255, 255, 255, 0))
+    draw = ImageDraw.Draw(text_frame)
+    draw.text((0, 135 - text_name_h), text_name, font=font, fill="black")
+    draw.text((0, 145), text_follow, font=font, fill="grey")
+    frame.paste(text_frame, (300, 0), mask=text_frame)
+
+    return save_jpg(frame)
+
+
+async def my_friend(
+    users: List[UserInfo], args: List[str] = [], **kwargs
+) -> Union[str, BytesIO]:
+    img = users[0].img
+    if not args:
+        return "你朋友说啥？"
+    elif len(args) <= 1:
+        name = users[0].name or "朋友"
+        text = args[0]
+    else:
+        name = args[0] or "朋友"
+        text = args[1]
+    text = text.replace("他", "我").replace("她", "我").replace("它", "我")
+
+    name_font = await load_font(DEFAULT_FONT, 25)
+    text_font = await load_font(DEFAULT_FONT, 40)
+    name_w, name_h = name_font.getsize(name)
+    text_w, text_h = text_font.getsize(text)
+    if name_w >= 800:
+        return "名字太长了哦，改短点再试吧~"
+    if text_w >= 1000:
+        return "文本太长了哦，改短点再试吧~"
+
+    dialog_left = await load_image("my_friend/0.png")
+    dialog_right = await load_image("my_friend/1.png")
+    dialog_box = Image.new("RGBA", (max(text_w, name_w + 15) + 140, 150))
+    dialog_box.paste(dialog_left, (0, 0))
+    dialog_box.paste(Image.new("RGBA", (text_w, 110), "#ffffff"), (70, 20))
+    dialog_box.paste(dialog_right, (text_w + 70, 0))
+    draw = ImageDraw.Draw(dialog_box)
+    draw.text((70, 15 + (110 - text_h) / 2), text, font=text_font, fill="#000000")
+
+    img = resize(circle(img), (100, 100))
+    frame = Image.new("RGBA", (dialog_box.width + 130, 210), "#eaedf4")
+    frame.paste(img, (20, 20), mask=img)
+    frame.paste(dialog_box, (130, 60), mask=dialog_box)
+    label = await load_image("my_friend/2.png")
+    frame.paste(label, (160, 25))
+    draw = ImageDraw.Draw(frame)
+    draw.text((260, 22 + (35 - name_h) / 2), name, font=name_font, fill="#868894")
+    return save_jpg(frame)
+
+
+async def paint(users: List[UserInfo], **kwargs) -> BytesIO:
+    img = users[0].img
+    img = to_jpg(img).convert("RGBA")
+    bg = await load_image("paint/0.png")
+    frame = Image.new("RGBA", bg.size, (255, 255, 255, 0))
+    frame.paste(rotate(fit_size(img, (117, 135)), 4), (95, 107))
+    frame.paste(bg, mask=bg)
+    return save_jpg(frame)
+
+
+async def shock(users: List[UserInfo], **kwargs) -> BytesIO:
+    img = users[0].img
+    img = resize(img, (300, 300))
+    frames = []
+    # fmt: off
+    params = [
+        (15, 0, 30), (-15, 90, 10), (-15, -45, 25), (-15, 45, 10),
+        (15, 45, 20), (0, -60, 30), (-10, 20, 10), (-15, 0, 0),
+        (-20, 0, 0), (0, 90, 40), (0, -70, 20), (0, 0, 20),
+        (-10, 90, 5), (-20, 90, 40), (-10, 0, 0), (15, 90, 10),
+        (10, 0, 10), (10, 0, 5), (-20, 90, 5), (-5, -45, 20),
+        (15, 0, 5), (0, 90, 5), (10, 80, 10), (-15, -45, 20),
+        (0, 0, 20), (20, 0, 10), (0, 45, 30), (-10, 90, 5),
+        (15, 0, 5), (-10, 0, 5)
+    ]
+    # fmt: on
+    for angle, blur_angle, blur_degree in params:
+        frames.append(
+            rotate(motion_blur(img, blur_angle, blur_degree), angle, expand=False)
+        )
+    return save_gif(frames, 0.001)
+
+
+async def coupon(
+    users: List[UserInfo], args: List[str] = [], **kwargs
+) -> Union[str, BytesIO]:
+    img = users[0].img
+    bg = await load_image("coupon/0.png")
+    new_img = rotate(resize(circle(img), (60, 60)), 22)
+    bg.paste(new_img, (164, 85), mask=new_img)
+
+    font = await load_font(DEFAULT_FONT, 30)
+    text_img = Image.new("RGBA", (250, 100))
+    text = f"{users[0].name}陪睡券" if not args else args[0]
+    text += "\n（永久有效）"
+    text_w = font.getsize_multiline(text)[0]
+    if text_w > text_img.width:
+        return "文字太长了哦，改短点再试吧~"
+
+    draw = ImageDraw.Draw(text_img)
+    draw.multiline_text(
+        ((text_img.width - text_w) / 2, 0),
+        text,
+        font=font,
+        align="center",
+        fill="#000000",
+    )
+    text_img = rotate(text_img, 22)
+    bg.paste(text_img, (94, 108), mask=text_img)
+    return save_jpg(bg)
